# Generated by Django 2.2.1 on 2019-05-31 09:58

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('measurements', '0003_auto_20190529_0513'),
    ]

    operations = [
        migrations.AlterField(
            model_name='serie',
            name='stats_mean',
            field=models.FloatField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='serie',
            name='stats_outliers',
            field=django.contrib.postgres.fields.ArrayField(base_field=models.IntegerField(), blank=True, null=True, size=None),
        ),
        migrations.AlterUniqueTogether(
            name='measure',
            unique_together={('serie', 'timestamp', 'value')},
        ),
    ]
