# Generated by Django 2.2.1 on 2019-06-19 14:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('measurements', '0004_auto_20190531_0958'),
    ]

    operations = [
        migrations.AddField(
            model_name='serie',
            name='height',
            field=models.FloatField(blank=True, null=True),
        ),
    ]
