# Generated by Django 2.2.1 on 2019-05-29 05:13

from django.db import migrations

def load_unknown_sensor(apps, schema_editor):
    Sensor = apps.get_model('measurements', 'Sensor')
    Sensor.objects.create(code="unknown", label="Unknown sernsor")

class Migration(migrations.Migration):

    dependencies = [
        ('measurements', '0002_auto_20190528_1557'),
    ]

    operations = [
        migrations.RunPython(load_unknown_sensor)
    ]
